@@ -192,34 +192,34 @@ void Account::setAlbumList(const AlbumList& list)
     this->profile.setAlbumList(list, this->transport->accountId, this->profile.ownerId);
 }
 
-MessageList Account::getInboxMessageList()
+MessageList Account::getMessageList()
 {
-    if (!this->inboxMessages.isEmpty())
-        return this->inboxMessages;
+    if (!this->messages.isEmpty())
+        return this->messages;
 
     // try to load message list
-    QFile file(Utils::getAccountDir(this->transport->accountId) + QString(FILE_INBOX_DATA));
+    QFile file(Utils::getAccountDir(this->transport->accountId) + QString(FILE_MESSAGES_DATA));
     if (file.open(QIODevice::ReadOnly) == false)
-        return this->inboxMessages;
+        return this->messages;
 
     QDomDocument doc;
     doc.setContent(&file);
     file.close();
 
-    this->inboxMessages.clear();
+    this->messages.clear();
     QDomNodeList lst = doc.elementsByTagName(NODE_MESSAGE_ROOT);
 
     qDebug() << "Start load of " << lst.length() << " messages";
     for (uint i = 0; i < lst.length(); i++) {
-        this->inboxMessages.append(Message::fromQDomElement(lst.at(i).toElement(), this->transport->accountId));
+        this->messages.append(Message::fromQDomElement(lst.at(i).toElement(), this->transport->accountId));
     }
 
-    return this->inboxMessages;
+    return this->messages;
 }
 
-void Account::setInboxMessageList(const MessageList& newMessages)
+void Account::setMessageList(const MessageList& newMessages)
 {
-    this->inboxMessages = newMessages;
+    this->messages = newMessages;
 
     // store friends into cache
     QDomDocument out("MyDoc");
@@ -236,61 +236,7 @@ void Account::setInboxMessageList(const MessageList& newMessages)
     if (!dir.exists())
         dir.mkpath(dir.absolutePath());
 
-    QFile file(dir.absolutePath() + QString(FILE_INBOX_DATA));
-    qDebug() << file.fileName();
-    if (file.open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Truncate) == false) {
-        qDebug() << "can't open file: " + file.errorString();
-    }
-
-    file.write(out.toByteArray(1));
-    file.close();
-}
-
-MessageList Account::getOutboxMessageList()
-{
-    if (!this->outboxMessages.isEmpty())
-        return this->outboxMessages;
-
-    // try to load message list
-    QFile file(Utils::getAccountDir(this->transport->accountId) + QString(FILE_OUTBOX_DATA));
-    if (file.open(QIODevice::ReadOnly) == false)
-        return this->outboxMessages;
-
-    QDomDocument doc;
-    doc.setContent(&file);
-    file.close();
-
-    this->outboxMessages.clear();
-    QDomNodeList lst = doc.elementsByTagName(NODE_MESSAGE_ROOT);
-
-    qDebug() << "Start load of " << lst.length() << " messages";
-    for (uint i = 0; i < lst.length(); i++) {
-        this->outboxMessages.append(Message::fromQDomElement(lst.at(i).toElement(), this->transport->accountId));
-    }
-
-    return this->outboxMessages;
-}
-
-void Account::setOutboxMessageList(const MessageList& newMessages)
-{
-    this->outboxMessages = newMessages;
-
-    // store friends into cache
-    QDomDocument out("MyDoc");
-    QDomElement profile = out.createElement(NODE_MESSAGES_ROOT);
-    out.appendChild(profile);
-
-    for (int i = 0; i < newMessages.length(); i++) {
-        profile.appendChild(Message::toQDomElement(out, newMessages[i]));
-    }
-
-    QDir dir;
-
-    dir.setPath(dir.cleanPath(Utils::getAccountDir(this->transport->accountId)));
-    if (!dir.exists())
-        dir.mkpath(dir.absolutePath());
-
-    QFile file(dir.absolutePath() + QString(FILE_OUTBOX_DATA));
+    QFile file(dir.absolutePath() + QString(FILE_MESSAGES_DATA));
     qDebug() << file.fileName();
     if (file.open(QIODevice::WriteOnly | QIODevice::Text | QIODevice::Truncate) == false) {
         qDebug() << "can't open file: " + file.errorString();
@@ -326,6 +272,8 @@ void Account::setDraftMessages(const MessageList &newMessages)
 
     file.write(out.toByteArray(1));
     file.close();
+
+    emit draftsUpdated(newMessages);
 }
 
 MessageList Account::getDraftMessages()
@@ -350,6 +298,7 @@ MessageList Account::getDraftMessages()
         this->draftMessages.append(Message::fromQDomElement(lst.at(i).toElement(), this->transport->accountId));
     }
 
+    emit draftsUpdated(this->draftMessages);
     return this->draftMessages;
 }
 
