@@ -34,16 +34,22 @@ QDomElement Album::toQDomElement(QDomDocument& doc) const
     node.appendChild(t);
 
     // Name
-    node = doc.createElement(NODE_ALBUM_TITLE);
-    t = doc.createTextNode(this->title);
-    ret.appendChild(node);
-    node.appendChild(t);
+    if (!this->title.isEmpty())
+    {
+        node = doc.createElement(NODE_ALBUM_TITLE);
+        t = doc.createTextNode(this->title);
+        ret.appendChild(node);
+        node.appendChild(t);
+    }
 
     // description
-    node = doc.createElement(NODE_ALBUM_DESCRIPTION);
-    t = doc.createTextNode(this->description);
-    ret.appendChild(node);
-    node.appendChild(t);
+    if (!this->description.isEmpty())
+    {
+        node = doc.createElement(NODE_ALBUM_DESCRIPTION);
+        t = doc.createTextNode(this->description);
+        ret.appendChild(node);
+        node.appendChild(t);
+    }
 
     // size
     node = doc.createElement(NODE_ALBUM_SIZE);
@@ -52,29 +58,40 @@ QDomElement Album::toQDomElement(QDomDocument& doc) const
     node.appendChild(t);
 
     //time create
-    node = doc.createElement(NODE_ALBUM_CREATE);
-    t = doc.createTextNode(this->time_create);
-    ret.appendChild(node);
-    node.appendChild(t);
+    if (!this->time_create.isEmpty())
+    {
+        node = doc.createElement(NODE_ALBUM_CREATE);
+        t = doc.createTextNode(this->time_create);
+        ret.appendChild(node);
+        node.appendChild(t);
+    }
 
     //time update
-    node = doc.createElement(NODE_ALBUM_UPDATE);
-    t = doc.createTextNode(this->time_update);
-    ret.appendChild(node);
-    node.appendChild(t);
+    if (!this->time_update.isEmpty())
+    {
+        node = doc.createElement(NODE_ALBUM_UPDATE);
+        t = doc.createTextNode(this->time_update);
+        ret.appendChild(node);
+        node.appendChild(t);
+    }
 
     //icon
-    node = doc.createElement(NODE_ALBUM_ICON);
-    t = doc.createTextNode(this->icon);
-    ret.appendChild(node);
-    node.appendChild(t);
+    if (!this->icon.isEmpty())
+    {
+        node = doc.createElement(NODE_ALBUM_ICON);
+        t = doc.createTextNode(this->icon);
+        ret.appendChild(node);
+        node.appendChild(t);
+    }
 
     //icon url
-    node = doc.createElement(NODE_ALBUM_ICON_URL);
-    t = doc.createTextNode(this->icon_url);
-    ret.appendChild(node);
-    node.appendChild(t);
-
+    if (!this->icon_url.isEmpty())
+    {
+        node = doc.createElement(NODE_ALBUM_ICON_URL);
+        t = doc.createTextNode(this->icon_url);
+        ret.appendChild(node);
+        node.appendChild(t);
+    }
 
     return ret;
 }
@@ -84,13 +101,21 @@ Album Album::fromQDomElement(const QDomElement& fr, const QString& accountId, co
     Album ret = Album();
 
     ret.albumId = fr.elementsByTagName(NODE_ALBUM_ID).at(0).firstChild().toText().data();
-    ret.title = fr.elementsByTagName(NODE_ALBUM_TITLE).at(0).firstChild().toText().data();
-    ret.icon = fr.elementsByTagName(NODE_ALBUM_ICON).at(0).firstChild().toText().data();
-    ret.icon_url = fr.elementsByTagName(NODE_ALBUM_ICON_URL).at(0).firstChild().toText().data();
-    ret.description = fr.elementsByTagName(NODE_ALBUM_DESCRIPTION).at(0).firstChild().toText().data();
-    ret.time_create = fr.elementsByTagName(NODE_ALBUM_CREATE).at(0).firstChild().toText().data();
-    ret.time_update = fr.elementsByTagName(NODE_ALBUM_UPDATE).at(0).firstChild().toText().data();
-    ret.size = fr.elementsByTagName(NODE_ALBUM_SIZE).at(0).firstChild().toText().data().toInt();
+    if (fr.elementsByTagName(NODE_ALBUM_TITLE).count() > 0)
+        ret.title = fr.elementsByTagName(NODE_ALBUM_TITLE).at(0).firstChild().toText().data();
+    if (fr.elementsByTagName(NODE_ALBUM_ICON).count() > 0)
+        ret.icon = fr.elementsByTagName(NODE_ALBUM_ICON).at(0).firstChild().toText().data();
+    if (fr.elementsByTagName(NODE_ALBUM_ICON_URL).count() > 0)
+        ret.icon_url = fr.elementsByTagName(NODE_ALBUM_ICON_URL).at(0).firstChild().toText().data();
+    if (fr.elementsByTagName(NODE_ALBUM_DESCRIPTION).count() > 0)
+        ret.description = fr.elementsByTagName(NODE_ALBUM_DESCRIPTION).at(0).firstChild().toText().data();
+    if (fr.elementsByTagName(NODE_ALBUM_CREATE).count() > 0)
+        ret.time_create = fr.elementsByTagName(NODE_ALBUM_CREATE).at(0).firstChild().toText().data();
+    if (fr.elementsByTagName(NODE_ALBUM_UPDATE).count() > 0)
+        ret.time_update = fr.elementsByTagName(NODE_ALBUM_UPDATE).at(0).firstChild().toText().data();
+    if (fr.elementsByTagName(NODE_ALBUM_SIZE).count() > 0)
+        ret.size = fr.elementsByTagName(NODE_ALBUM_SIZE).at(0).firstChild().toText().data().toInt();
+
     ret.accountId = accountId;
     ret.ownerId = friendId;
 
