@@ -10,6 +10,7 @@
 
 #include "widgets/qimageviewer.h"
 #include "widgets/qtoppanel.h"
+#include "widgets/friends/qfriendlistwidget.h"
 #include "utils/hintedit.h"
 
 #include "datatypes/friend.h"
@@ -22,13 +23,15 @@ namespace Ui {
     class ImageBrowserPanel;
 }
 
+class AlbumInfoWidget;
+class ProfileBrowser;
 class ImageBrowserPanel : public QWidget
 {
     Q_OBJECT
 
 public:
-    explicit ImageBrowserPanel(QWidget *parent = 0);
-    explicit ImageBrowserPanel(ServiceMgr *mgr, QWidget *parent = 0);
+    explicit ImageBrowserPanel(QFont usedFont, QWidget *parent = 0);
+    explicit ImageBrowserPanel(QFont usedFont, ServiceMgr *mgr, QWidget *parent = 0);
     ~ImageBrowserPanel();
 
     void init();
@@ -57,25 +60,23 @@ public:
 
 private:
     void setAlbumHeader();
-    void setAlbumHeader(Friend fr);
+    void setAlbumHeader(const Friend& fr);
     void setPhotoHeader();
     void setPhotoHeader(Album al);
     static QString albumItem(const Album& al);
     static QPixmap albumIcon(const Album& al);
-    static QPixmap photoIcon(const Photo& al);
+    QPixmap photoIcon(const Photo& al);
     static QPixmap photoIcon(const QAttachment& al);
 
 
 private:
     Ui::ImageBrowserPanel *ui;
+    QFriendListWidget *friendsPanel;
     QTopPanel *albumsTopPanel;
     QTopPanel *photosTopPanel;
 
     QFont usedFont;
 
-    //QLabel lablContacts;
-    HintEdit *editOwnr;
-    QPushButton *buttonEditOwnr;
     QPushButton *buttonRefreshFriends;
     QRadioButton *peopleradb;
     QRadioButton *newsradb;
@@ -84,7 +85,8 @@ private:
     //QPushButton *buttonCloseAlbums;
     //QPushButton *buttonClosePhotos;
 
-    bool isSkipFriendUpdate;
+    AlbumInfoWidget* albumInfoWidget;
+    ProfileBrowser* profileInfoWidget;
 
     ServiceMgr *sm;
 
@@ -93,11 +95,14 @@ private:
     bool isPhotosUpdate;
     bool isFeedUpdate;
 
+    bool isPhotosWidthSet;
+    int photosWidth;
+
     // current state for window
     WindowState state;
     bool isPortraitMode;
 
-    void ownrSelected(QListWidgetItem *item, bool isNeedUpdateState);
+    void ownrSelected(Friend fr, bool isNeedUpdateState);
 
     QListWidgetItem *createFriendWidget(Friend fr);
     void addMeToFriends();
@@ -110,11 +115,7 @@ signals:
     void showAlbumInfo(Album al);
 
 private slots:
-    //void on_pushButtonMe_toggled(bool checked);
-    void editOwnr_textChanged(QString str);
-    void buttonResetOwnr_clicked();
-
-    void ownrSelected(QListWidgetItem *item);
+    void ownrSelected(Friend item);
     void albmSelected(QListWidgetItem *item);
     void photoSelected(QListWidgetItem *item);
     void feedEventSelected(QListWidgetItem *item);
@@ -146,8 +147,6 @@ private slots:
     void updateListPhotos(QString accountId, QString ownerId, QString albumId, PhotoList, bool isLastUpdate);
     void updateFeed(QEventFeedList list, QEventFeed::FeedType type, bool isLastUpdate);
 
-    void disableFriendSkipUpdate();
-
     void updateAccounts(QString accountId, AccountList list);
 };
 
