@@ -20,6 +20,12 @@
 #include <QDomElement>
 #include <QDateTime>
 
+#if QT_VERSION >= 0x040700
+# include <QElapsedTimer>
+#else
+# include <QTime>
+#endif
+
 #include "mysocials_driver.h"
 
 #include "datatypes/driverinfo.h"
@@ -64,8 +70,7 @@ public:
         deleteFriendAction, /**< \brief Class: friends. Method: deleteFriend. */
         getSettingsAction, /**< \brief Class: settings. Method: getSettings. */
         setSettingsAction, /**< \brief Class: settings. Method: setSettings. */
-        getOutboxMessagesAction, /**< \brief Class: messages. Method: getListOutboxMessages. */
-        getInboxMessagesAction, /**< \brief Class: messages. Method: getListInboxMessages. */
+        getMessagesAction, /**< \brief Class: messages. Method: getListOutboxMessages. */
         sendMessageAction, /**< \brief Class: messages. Method: sendMessage. */
         readMessageAction, /**< \brief Class: messages. Method: readMessage. */
         deleteMessageAction, /**< \brief Class: messages. Method: deleteMessage. */
@@ -78,6 +83,8 @@ public:
         getFeedAction /**< \brief Class: news. Method: getListNews. */
     };
 
+    bool checkFunction(const QString &usedClass, const QString &usedFunction) const;
+
 private:
     // Pointer to social network driver library
     QLibrary *driver;
@@ -94,6 +101,13 @@ private:
     // true if library init well
     bool isLibraryInit;
 
+    #if QT_VERSION >= 0x040700
+    QElapsedTimer timer;
+    #else
+    QTime timer;
+    #endif
+
+
     // list of registered functions
     QList<MethodElement> registerdFunctions;
 
@@ -112,6 +126,24 @@ private:
 
     QAttachment loadAttachment(const QDomElement& node);
 
+    /*!
+        \brief load inbox messages if service support inbox/outbox model.
+        Use \a getMessages instead of this function for universal access.
+      */
+    MessageList getInbox();
+
+    /*!
+      \brief load sent messages if service support inbox/outbox model.
+      Use \a getMessages instead of this function for universal access.
+      */
+    MessageList getOutbox();
+
+    /*!
+      \brief load messages from threads if service support thread model.
+      Use \a getMessages instead of this function for universal access.
+      */
+    MessageList getThreadList();
+
 public:
     QTransport(QString libName, QString accName, QObject *parent = 0);
     ~QTransport();
@@ -128,7 +160,7 @@ public:
 
     QString serviceName() const;
 
-    QString generateFileName(const QString& path, const QString& url) const;
+    static QString generateFileName(const QString& path, const QString& url);
 
     DriverInfo *getDriverInfo();
     static DriverInfo *getDriverInfo(QString libraryPath);
@@ -154,12 +186,12 @@ public:
       */
     void getProfile(const QString& ownerId);
 
-    void getFriends();
+    void getFriends(bool alsoLoadIcons);
     bool deleteFriend(QString ownerId);
     bool deleteFriend(Friend owner);
 
-    void getAlbums(QString ownedId);
-    void getPhotos(QString ownerId, QString albumId);
+    void getAlbums(QString ownedId, bool alsoLoadIcons);
+    void getPhotos(QString ownerId, QString albumId, bool alsoLoadIcons);
     void getPhotoComments(Photo photo);
     bool sendPhotoComment(Photo photo, QString comment);
     bool uploadPhoto(QString accountId, QString albumId, QString file_name, QString description);
@@ -167,9 +199,12 @@ public:
     bool downloadPhoto(QString url, QString local_file_name);
     void downloadPhotoList(PhotoList list, Photo curPhoto, int nearest);
 
-    void getInbox();
-    void getOutbox();
-    void getThreadList();
+    /*!
+      \brief loalist of messages from service.
+
+      Uses \a getInbox(), \a getOutbox() and \a getThreads().
+      */
+    void getMessages();
     bool sendMessage(QString ownerId, QString title, QString message);
     bool sendMessage(Friend owner, QString title, QString message);
     bool readMessage(QString messageId);
@@ -196,8 +231,7 @@ signals:
     void settingsReceived(QString accountid, QString) const;
     void profileReceived(QString accountId, QString reqOwnerId, Friend data);
 
-    void inboxMessagesReceived(QString accountId, MessageList list, bool isLastUpdate);
-    void outboxMessagesReceived(QString accountId, MessageList list, bool isLastUpdate);
+    void messagesReceived(QString accountId, MessageList list, bool isLastUpdate);
     void messageSended(QString accountId, QString ownerId, QString title, QString text);
     void messageReaded(QString accountId, QString messageId);
     void messageDeleted(QString accountId, QString messageId);
@@ -227,6 +261,8 @@ class QTransport
 #define DRV_ACCESS_ERROR QT_TR_NOOP("Operation prohibited by privacy")
 #define DRV_SERVER_ERROR QT_TR_NOOP("Internal Server Error")
 #define DRV_FILE_SAVE_ERROR QT_TR_NOOP("Can't save file")
+QT_TR_NOOP("male")
+QT_TR_NOOP("female")
 
 // from libvkontakte - errors.xml
 QT_TR_NOOP("Incorrect signature")
