@@ -36,7 +36,21 @@ ServiceMgr::ServiceMgr(QObject *parent) :
     if (!settings->contains(SETTINGS_PROXY))
         settings->setValue(SETTINGS_PROXY, this->SystemProxy);
     if (!settings->contains(SETTINGS_MULTIPANEL))
+    {
+#ifdef Q_WS_MAEMO_5
+        settings->setValue(SETTINGS_MULTIPANEL, false);
+#else
         settings->setValue(SETTINGS_MULTIPANEL, true);
+#endif
+    }
+
+#ifdef Q_WS_MAEMO_5
+    if (!settings->contains(SETTINGS_AUTOROTATE))
+    {
+        settings->setValue(SETTINGS_AUTOROTATE, true);
+    }
+#endif
+
     loadAccounts();
 
     qDebug()<< "loaded " << this->accounts.length() << " accounts";
