@@ -1,5 +1,7 @@
 #include "qimageviewer.h"
 
+#include "datatypes/photo.h"
+
 QImageViewer::QImageViewer(QFont textFont, QWidget *parent) :
     QMainWindow(parent), windowSize(QSize()), currentImageIndex(-1)
 {
@@ -113,9 +115,11 @@ void QImageViewer::loadImage(ServiceMgr *sm, Photo image)
     setWindowTitle(tr(WINDOW_TITLE));
     this->showMaximized();
 
-    this->list = this->sm->getPhotosForAlbum(this->currentPhoto);
+    if (!this->currentPhoto.albumId.isEmpty())
+        this->list = this->sm->getPhotosForAlbum(this->currentPhoto);
     if (this->list.isEmpty())
         qDebug() <<__FILE__ <<":" << __LINE__ << ":" << __FUNCTION__ << "() got empty photo list";
+
     for (int i = 0; i < this->list.length(); i++) {
         if (list.at(i).photoId == this->currentPhoto.photoId) {
             this->currentImageIndex = i;
@@ -133,13 +137,13 @@ void QImageViewer::loadImage(ServiceMgr *sm, Photo image)
     this->showImage(false);
 }
 
-void QImageViewer::imageListUpdate(QString accountId, QString friendId, QString albumId, PhotoList list, bool isLastUpdate)
+void QImageViewer::imageListUpdate(QString accountId, QString friendId, QString albumId, PhotoList lst, bool isLastUpdate)
 {
-    qDebug() <<__FILE__ <<":" << __LINE__ << ":" << __FUNCTION__ << "() got " << list.count() << " new images for album " << albumId << " isLastUpdate=" << isLastUpdate;
+    qDebug() <<__FILE__ <<":" << __LINE__ << ":" << __FUNCTION__ << "() got " << lst.count() << " new images for album " << albumId << " isLastUpdate=" << isLastUpdate;
     if (this->currentPhoto.accountId == accountId &&
         this->currentPhoto.ownerId == friendId &&
         this->currentPhoto.albumId == albumId)
-        this->list = list;
+        this->list = lst;
     else
         return;
 
@@ -154,8 +158,21 @@ void QImageViewer::imageListUpdate(QString accountId, QString friendId, QString
         if (list.at(i).photoId == this->currentPhoto.photoId)
         {
             this->currentImageIndex = i;
-            if (list.at(i).photo.isEmpty() && isLastUpdate)
-                this->sm->downloadPhotos(this->list.at(i), 1);
+            QString serviceName = this->sm->account(list.at(i).accountId)->serviceName();
+
+            QString iconPath = QTransport::generateFileName(Utils::getAlbumsIconDir(serviceName), list.at(i).icon_url);
+            if (list.at(i).icon.isEmpty() && QFile::exists(iconPath))
+                list[i].icon = iconPath;
+
+            if (list.at(i).photo.isEmpty())
+            {
+                QString photoPath = QTransport::generateFileName(Utils::getPhotoDir(serviceName), list.at(i).photo_url);
+                if (QFile::exists(photoPath))
+                    list[i].photo = photoPath;
+                else
+                    if (isLastUpdate)
+                        this->sm->downloadPhotos(this->list.at(i), 1);
+            }
             break;
         }
     }
